
TODO: Improve this readme.

# Gym Atari Examples

Demonstrations of deep reinforcement learning algorithms for Atari game environments implemented with cherry.

## Requirements

* Gym, torch, and cherry installed.

### Atari

#### Install instructions

```
pip install 'gym[atari]'
```

## Examples Descriptions

### DQN

**Status** Needs work.

### PPO

**Status** Needs work.

### Distributed A2C

**Status** Should be good, needs benchmark.

### Debugging Reinforcement Learning

**Status** Needs work.

